﻿* Encoding: UTF-8.
*Additivity Dominance: Study 4B
*Created by S.S.

*Excluding participants who didn't finish*

USE ALL.
COMPUTE filter_$=(excl.finish = 0).
VARIABLE LABELS filter_$ 'excl.finish = 0 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

*Age and Gender Descriptives*

FREQUENCIES VARIABLES=gender
  /ORDER=ANALYSIS.

COMPUTE age=2013-birthyear.
EXECUTE.

DESCRIPTIVES VARIABLES=age
  /STATISTICS=MEAN STDDEV MIN MAX.


*Valence score from +3 (all positive associations) to -3 (all negative associations)*

COMPUTE add.valence=(add.1.val+add.2.val+add.3.val - 6)*-1.
EXECUTE.

COMPUTE for.valence=(for.1.val+for.2.val+for.3.val - 6)*-1.
EXECUTE.

COMPUTE sup.valence=(sup.1.val+sup.2.val+sup.3.val - 6)*-1.
EXECUTE.


*Health score from +3 (all healthy) to -3 (all unhealthy)*

COMPUTE add.healthy=(add.1.hea+add.2.hea+add.3.hea - 6)*-1.
EXECUTE.

COMPUTE for.healthy=(for.1.hea+for.2.hea+for.3.hea - 6)*-1.
EXECUTE.

COMPUTE sup.healthy=(sup.1.hea+sup.2.hea+sup.3.hea - 6)*-1.
EXECUTE.

*Natural score from +3 (all natural) to -3 (all natural)*

COMPUTE add.natural=(add.1.nat+add.2.nat+add.3.nat - 6)*-1.
EXECUTE.

COMPUTE for.natural=(for.1.nat+for.2.nat+for.3.nat - 6)*-1.
EXECUTE.

COMPUTE sup.natural=(sup.1.nat+sup.2.nat+sup.3.nat - 6)*-1.
EXECUTE.


*Do synonyms vary in valence?*

GLM add.valence for.valence sup.valence
  /WSFACTOR=Synonym 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=Synonym.

T-TEST PAIRS=add.valence add.valence for.valence WITH for.valence sup.valence sup.valence (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


COMPUTE foradd.val.diff = for.valence-add.valence.
COMPUTE supadd.val.diff = sup.valence-add.valence.
COMPUTE forsup.val.diff = for.valence-sup.valence.
DESCRIPTIVES VARIABLES=foradd.val.diff supadd.val.diff forsup.val.diff
  /STATISTICS=MEAN STDDEV. /* divide mean by SD for repeated measures cohen's d.


*Do synonyms vary in healthfulness?*

GLM add.healthy for.healthy sup.healthy
  /WSFACTOR=Synonym 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=Synonym.

T-TEST PAIRS=add.healthy add.healthy for.healthy WITH for.healthy sup.healthy sup.healthy (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


COMPUTE foradd.hea.diff = for.healthy-add.healthy.
COMPUTE supadd.hea.diff = sup.healthy-add.healthy.
COMPUTE forsup.hea.diff = for.healthy-sup.healthy.
DESCRIPTIVES VARIABLES=foradd.hea.diff supadd.hea.diff forsup.hea.diff
  /STATISTICS=MEAN STDDEV. /* divide mean  SD for repeated measures cohen's d.


*Do synonyms vary in naturalness?*

GLM add.natural for.natural sup.natural
  /WSFACTOR=Synonym 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=Synonym.

T-TEST PAIRS=add.natural add.natural for.natural WITH for.natural sup.natural sup.natural (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

COMPUTE foradd.nat.diff = for.natural-add.natural.
COMPUTE supadd.nat.diff = sup.natural-add.natural.
COMPUTE forsup.nat.diff = for.natural-sup.natural.
DESCRIPTIVES VARIABLES=foradd.nat.diff supadd.nat.diff forsup.nat.diff
  /STATISTICS=MEAN STDDEV. /* divide mean  SD for repeated measures cohen's d.

